@@ -1,12 +1,12 @@
 package Media::Info::Mplayer;
 
-our $DATE = '2016-06-09'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Capture::Tiny qw(capture);
 use IPC::System::Options 'system', -log=>1;
@@ -102,7 +102,7 @@ Media::Info::Mplayer - Return information on media file/URL, using mplayer
 
 =head1 VERSION
 
-This document describes version 0.08 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2016-06-09.
+This document describes version 0.09 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,11 @@ Sample result:
 =head1 FUNCTIONS
 
 
-=head2 get_media_info(%args) -> [status, msg, result, meta]
+=head2 get_media_info
+
+Usage:
+
+ get_media_info(%args) -> [status, msg, result, meta]
 
 Return information on media file/URL, using mplayer.
 
@@ -189,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
